#!/bin/bash
#
# Copyright (C) 2014-2019 NetFlow Logic. All rights reserved.
#

ARG0="${0}"
while [ -h "${ARG0}" ]; do
	ls=$(ls -ld "${ARG0}")
	link=$(expr "${ls}" : '.*-> \(.*\)$')
	if $(expr "${link}" : '/.*' > /dev/null); then
		ARG0="${link}"
	else
		ARG0="$(dirname ${ARG0})/${link}"
	fi
done

declare appRoot="$(readlink -f $(dirname ${ARG0}))"
declare appName="$(basename ${ARG0})"
declare op=""

for arg in "${@}"
do
	case ${arg} in
		-java-home=*)
			JAVA_HOME="${arg/-java-home=/}"
		;;
		-nfiu-home=*)
			NFIU_HOME="${arg/-nfiu-home=/}"
		;;
		-nfiu-base=*)
			NFIU_BASE="${arg/-nfiu-base=/}"
		;;
		-nfiu-pid=*)
			NFIU_PID="${arg/-nfiu-pid=/}"
		;;
		-nfiu-user=*)
			NFIU_USER="${arg/-nfiu-user=/}"
		;;
		start | stop)
			if [[ -z "${op}" ]];then
				op="${arg}"
			fi
		;;
	esac
done

# Use the maximum available file descriptors
MAX_FD="maximum"
# Setup parameters for running the jsvc
#
if [[ -z "${NFIU_USER}" ]];then
	NFIU_USER=nfiu
fi
# Set JAVA_HOME to working JDK or JRE
# JAVA_HOME=/opt/jdk-1.6.0.22
# If not set we'll try to guess the JAVA_HOME
# from java binary if on the PATH
#
if [[ -z "${JAVA_HOME}" ]]; then
	JAVA_BIN="$(which java 2>/dev/null || type java 2>&1)"
	if [[ -x "${JAVA_BIN}" ]]; then
		JAVA_HOME="$(dirname $${JAVA_BIN})"
		if [[ -n "${JAVA_HOME}" ]];then
			JAVA_HOME=$(cd "${JAVA_HOME}/.." >/dev/null; pwd)
		fi
	fi
else
	JAVA_BIN="${JAVA_HOME}/bin/java"
fi

if [[ -z "${NFIU_HOME}" ]];then
	NFIU_HOME=$(cd "${appRoot}/.." >/dev/null; pwd)
fi

if [[ -z "${NFIU_BASE}" ]];then
	NFIU_BASE="${NFIU_HOME}"
fi
JSVC="${NFIU_BASE}/bin/jsvc"

CLASSPATH="${NFIU_BASE}/lib/*:${NFIU_BASE}/agents/*"
NFIU_MAIN=com.netflowlogic.updater.UpdaterBootstrap
NFIU_OUT="${NFIU_BASE}/logs/daemon.out"
NFIU_CONFIG="${NFIU_BASE}/conf/updater.properties"

# Set -pidfile
if [[ -z "${NFIU_PID}" ]];then
	NFIU_PID="${NFIU_BASE}/logs/nfiu-daemon.pid"
fi

# Increase the maximum file descriptors if we can
MAX_FD_LIMIT=$(ulimit -H -n)
if [[ "$?" -eq 0 ]]; then
	if [[ "${MAX_FD}" == "maximum" ]];then
		MAX_FD="${MAX_FD_LIMIT}"
	fi
	ulimit -n ${MAX_FD}
	if [[ "$?" -ne 0 ]]; then
		echo "${appName}: Could not set maximum file descriptor limit: ${MAX_FD}"
	fi
else
	echo "${appName}: Could not query system maximum file descriptor limit: ${MAX_FD_LIMIT}"
fi

JAVA_OPTS="-XX:ErrorFile=${NFIU_BASE}/logs/hs_err_pid%p.log -Xss1280k -Xms128m -Xmx3g"
if [ -r "${NFIU_BASE}/bin/setenv.sh" ]; then
	. "${NFIU_BASE}/bin/setenv.sh"
fi

case "${op}" in
		start)
			"${JSVC}" \
			-java-home "${JAVA_HOME}" \
			-user ${NFIU_USER} \
			-pidfile "${NFIU_PID}" \
			-wait 120 \
			-umask 91 \
			-outfile "${NFIU_OUT}" \
			-errfile "&1" \
			-server \
			-classpath "${CLASSPATH}" \
			${JAVA_OPTS} \
			${NFIU_MAIN} \
			--confFile="${NFIU_CONFIG}"
			exit $?
		;;
		stop)
			"${JSVC}" \
			-stop \
			-pidfile "${NFIU_PID}" \
			-classpath "${CLASSPATH}" \
			${NFIU_MAIN}
			exit $?
		;;
		*)
			echo "Unknown command: '${op}'"
			echo "Usage: ${appName} ( commands ... )"
			echo "commands:"
			echo "  start             Start External Data Feeder for NFO"
			echo "  stop              Stop External Data Feeder for NFO"
			exit 1
		;;
esac
